@@ -862,7 +862,7 @@ void InputFilter::parseServerCommand(const TQString &prefix, const TQString &com
                 when.setTime_t(parameterList[2].toUInt());
                 server->appendCommandMessageToChannel(parameterList[1],i18n("Created"),
                     i18n("This channel was created on %1.")
-                    .arg(when.toString(Qt::LocalDate))
+                    .arg(when.toString(TQt::LocalDate))
                     );
 
                 if(Preferences::autoWhoContinuousEnabled())
@@ -962,7 +962,7 @@ void InputFilter::parseServerCommand(const TQString &prefix, const TQString &com
                 {
                     server->appendCommandMessageToChannel(parameterList[1],i18n("Topic"),
                         i18n("The topic was set by %1 on %2.")
-                        .arg(parameterList[2]).arg(when.toString(Qt::LocalDate)),
+                        .arg(parameterList[2]).arg(when.toString(TQt::LocalDate)),
                         false);
                 }
                 else
@@ -970,7 +970,7 @@ void InputFilter::parseServerCommand(const TQString &prefix, const TQString &com
                     server->appendMessageToFrontmost(i18n("Topic"),i18n("The topic for %1 was set by %2 on %3.")
                         .arg(parameterList[1])
                         .arg(parameterList[2])
-                        .arg(when.toString(Qt::LocalDate))
+                        .arg(when.toString(TQt::LocalDate))
                         );
                     setAutomaticRequest("TOPIC",parameterList[1],false);
                 }
@@ -1535,7 +1535,7 @@ void InputFilter::parseServerCommand(const TQString &prefix, const TQString &com
                     {
                         server->appendMessageToFrontmost(i18n("Whois"),
                             i18n("%1 has been online since %2.")
-                            .arg(parameterList[1]).arg(when.toString(Qt::LocalDate))
+                            .arg(parameterList[1]).arg(when.toString(TQt::LocalDate))
                             );
                     }
                 }
@@ -1668,7 +1668,7 @@ void InputFilter::parseServerCommand(const TQString &prefix, const TQString &com
                     TQDateTime when;
                     when.setTime_t(parameterList[4].toUInt());
 
-                    server->appendMessageToFrontmost(i18n("BanList:%1").arg(parameterList[1]), i18n("BanList message: e.g. *!*@aol.com set by MrGrim on <date>", "%1 set by %2 on %3").arg(parameterList[2]).arg(parameterList[3].section('!', 0, 0)).arg(when.toString(Qt::LocalDate)));
+                    server->appendMessageToFrontmost(i18n("BanList:%1").arg(parameterList[1]), i18n("BanList message: e.g. *!*@aol.com set by MrGrim on <date>", "%1 set by %2 on %3").arg(parameterList[2]).arg(parameterList[3].section('!', 0, 0)).arg(when.toString(TQt::LocalDate)));
                 }
                 break;
             }
@@ -1980,6 +1980,3 @@ void InputFilter::parsePrivMsg(const TQString& prefix,
 }
 
 #include "inputfilter.moc"
-
-// kate: space-indent on; tab-width 4; indent-width 4; mixed-indent off; replace-tabs on;
-// vim: set et sw=4 ts=4 cino=l1,cs,U1:
