@@ -14,13 +14,13 @@
 
 #include "chatwindow.h"
 
-#include <kparts/part.h>
+#include <tdeparts/part.h>
 
 
 class KonsolePanel : public ChatWindow
 {
-    Q_OBJECT
-  TQ_OBJECT
+    TQ_OBJECT
+  
 
     public:
         explicit KonsolePanel(TQWidget *p);
