@@ -20,7 +20,7 @@ class MultilineTextEdit;
 
 class MultilineEdit : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
         public:
